==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/es_MX.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "%s password reset" : "%s restablecer contraseña",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mier.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Settings" : "Ajustes",
    "Saving..." : "Guardando...",
    "seconds ago" : "hace segundos",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "Which files do you want to keep?" : "¿Que archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Error setting expiration date" : "Error estableciendo fecha de caducidad",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Caducidad",
    "Expiration date" : "Fecha de caducidad",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Share link" : "Enlace compartido",
    "Password protect" : "Protección con contraseña",
    "Password" : "Contraseña",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar al usuario por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Warning" : "Precaución",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "Please reload the page." : "Vuelva a cargar la página.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Error loading tags" : "Error cargando etiquetas.",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error borrando etiqueta(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al quitar etiqueta",
    "Error favoriting" : "Error al marcar como favorito",
    "Error unfavoriting" : "Error al quitar como favorito",
    "Access forbidden" : "Acceso denegado",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando …",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "Log in" : "Entrar",
    "Alternative Logins" : "Accesos Alternativos",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "New password" : "Nueva contraseña",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/es_MX.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "%s password reset" : "%s restablecer contraseña",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mier.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Settings" : "Ajustes",
    "Saving..." : "Guardando...",
    "seconds ago" : "hace segundos",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "Which files do you want to keep?" : "¿Que archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Error setting expiration date" : "Error estableciendo fecha de caducidad",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Caducidad",
    "Expiration date" : "Fecha de caducidad",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Share link" : "Enlace compartido",
    "Password protect" : "Protección con contraseña",
    "Password" : "Contraseña",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar al usuario por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Warning" : "Precaución",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "Please reload the page." : "Vuelva a cargar la página.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Error loading tags" : "Error cargando etiquetas.",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error borrando etiqueta(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al quitar etiqueta",
    "Error favoriting" : "Error al marcar como favorito",
    "Error unfavoriting" : "Error al quitar como favorito",
    "Access forbidden" : "Acceso denegado",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando …",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "Log in" : "Entrar",
    "Alternative Logins" : "Accesos Alternativos",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "New password" : "Nueva contraseña",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona."
},
"nplurals=2; plural=(n != 1);");
